@@ -2,7 +2,7 @@
 kleenex.plugin
 ~~~~~~~~~~~~~~
 
-:copyright: 2011 David Cramer.
+:copyright: 2011 DISQUS.
 :license: BSD
 """
 
@@ -13,7 +13,6 @@ import os
 import simplejson
 import sys
 import time
-import traceback
 
 from coverage import coverage
 from coverage.report import Reporter
@@ -33,7 +32,8 @@ def is_py_script(filename):
         return False
     else:
         try:
-            first_line = open(filename, "r").next().strip()
+            with open(filename, "r") as fp:
+                first_line = fp.readline().strip()
             return "#!" in first_line and "python" in first_line
         except StopIteration:
             return False
@@ -42,11 +42,8 @@ def _get_git_revision(path):
     revision_file = os.path.join(path, 'refs', 'heads', 'master')
     if not os.path.exists(revision_file):
         return None
-    fh = open(revision_file, 'r')
-    try:
-        return fh.read()
-    finally:
-        fh.close()
+    with open(revision_file, 'r') as fp:
+        return fp.read()
 
 class TestCoveragePlugin(Plugin):
     """
@@ -148,6 +145,7 @@ class TestCoveragePlugin(Plugin):
         self.logger = logging.getLogger(__name__)
         self.dsn = options.coverage_dsn
         self.parent = options.coverage_parent
+        self.coverage_max_proximity = 4
         # self.enabled = (self.record or self.report_coverage or self.discover)
 
         if not self.enabled:
@@ -359,24 +357,13 @@ class TestCoveragePlugin(Plugin):
         for filename in cov.data.measured_files():
             linenos.extend(cov.data.executed_lines(filename).values())
 
-        total_prox = sum(linenos)
-        if total_prox:
-            num_vals = len(linenos)
-            mean_prox = total_prox / num_vals
-            stddev_prox = (sum([(l - mean_prox)**2 for l in linenos]) / num_vals)^2
-            min_prox = mean_prox - stddev_prox
-            max_prox = mean_prox + stddev_prox
-
         for cu in rep.code_units:
             # if sys.modules[test_.__module__].__file__ == cu.filename:
             #     continue
             filename = cu.name + '.py'
             linenos = cov.data.executed_lines(cu.filename)
-            if total_prox:
-                linenos_in_prox = [k for k, v in linenos.iteritems() if v <= max_prox and v >= min_prox]
-            else:
-                linenos_in_prox = linenos
-            if self.record:
+            linenos_in_prox = dict((k, v) for k, v in linenos.iteritems() if v < self.coverage_max_proximity)
+            if self.record and linenos_in_prox:
                 self.db.set_test_coverage(test_name, filename, linenos_in_prox)
             if self.report_coverage:
                 diff = self.diff_data[filename]
